{{- $resources := (list) -}}
{{- range .Values.gatekeeper.resources -}}
{{-   $resource := (dict) -}}
{{-   $_ := set $resource "uri" .uri -}}
{{-   $_ := set $resource "roles" (default (list) .roles) -}}
{{-   $resources = append $resources $resource -}}
{{- end -}}

# the interface the service should be listening on
listen: "{{ .Values.gatekeeper.listen }}"
# discovery url to retrieve the openid configuration
discovery-url: "{{ .Values.gatekeeper.discoveryUrl }}"
# client id used to authenticate to the oauth service
client-id: "{{ .Values.gatekeeper.clientId }}"
# client secret used to authenticate to the oauth service
client-secret: "{{ .Values.gatekeeper.clientSecret }}"
# redirection url for the oauth callback url, defaults to host header is absent
redirection-url: "{{ .Values.gatekeeper.redirectionUrl }}"
# url for the upstream endpoint you wish to proxy
upstream-url: "{{ .Values.gatekeeper.upstreamUrl }}"
# enable http logging of the requests
enable-logging: {{ default false .Values.gatekeeper.enableLogging }}
# adds the authorization header to the proxy request
enable-authorization-header: {{ default false .Values.gatekeeper.enableAuthHeader }}
# switch on debug / verbose logging
verbose: {{ default false .Values.gatekeeper.verbose }}
# enforces the cookie to be secure
secure-cookie: {{ .Values.gatekeeper.secureCookie }}

enable-refresh-tokens: {{ default false .Values.gatekeeper.refreshTokens.enabled }}
{{- if .Values.gatekeeper.refreshTokens.encryptToken }}
enable-encrypted-token: {{ .Values.gatekeeper.refreshTokens.encryptToken }}
encryption-key: {{ include "iam-proxy.encryptionKey" . }}
{{- end }}

{{- if .Values.gatekeeper.tls.enabled }}
# path to ths TLS certificate
tls-cert: {{ .Values.gatekeeper.tls.cert }}
# path to the private key for TLS
tls-private-key: {{ .Values.gatekeeper.tls.key }}
# path to the ca certificate used for signing requests
tls-ca-certificate: {{ .Values.gatekeeper.tls.ca.cert }}
# path the ca private key, used by the forward signing proxy
tls-ca-key: {{ .Values.gatekeeper.tls.ca.key }}
# path to the client certificate for outbound connections in reverse and forwarding proxy modes
tls-client-certificate: {{ .Values.gatekeeper.tls.client.cert }}
{{- end }}

{{- if .Values.gatekeeper.tls.upstreamCa }}
# the path to a file container a CA certificate to validate the upstream tls endpoint
upstream-ca: {{ .Values.gatekeeper.tls.upstreamCa }}
{{- end }}

# skip the verification of any upstream TLS
skip-upstream-tls-verify: {{ default false .Values.gatekeeper.skipUpstreamTlsVerify }}
# TESTING ONLY; bypass token verification, only expiration and roles enforced
skip-token-verification: {{ default false .Values.gatekeeper.skipTokenVerification }}

{{- if .Values.gatekeeper.openid }}
{{- if .Values.gatekeeper.openid.skipTlsVerify }}
# skip the verification of any TLS communication with the openid provider
skip-openid-provider-tls-verify: {{ default false .Values.gatekeeper.openid.skipTlsVerify }}
{{- end }}
{{- if .Values.gatekeeper.openid.providerProxy }}
# proxy for communication with the openid provider
openid-provider-proxy: "{{ .Values.gatekeeper.openid.providerProxy }}"
{{- end }}
{{- if .Values.gatekeeper.openid.providerTimeout }}
# timeout for openid configuration on .well-known/openid-configuration
openid-provider-timeout: {{ .Values.gatekeeper.openid.providerTimeout }}
{{- end }}
{{- end }}


{{- if .Values.gatekeeper.server }}
# server-read-timeout is the read timeout on the http server
server-read-timeout: {{ default  120000000000 .Values.gatekeeper.server.readTimeout }}
# server-write-timeout is the write timeout on the http server
server-write-timeout: {{ default  120000000000 .Values.gatekeeper.server.writeTimeout }}
# server-idle-timeout is the idle timeout on the http server
server-idle-timeout: {{ default  120000000000 .Values.gatekeeper.server.idleTimeout }}
{{- end }}
{{- if .Values.gatekeeper.upstream }}
# upstream-expect-continue-timeout is the timeout expect continue for upstream
upstream-expect-continue-timeout: {{ default  120000000000 .Values.gatekeeper.upstream.expectContinueTimeout }}
# upstream-response-header-timeout is the timeout for upstream header response
upstream-response-header-timeout: {{ default  120000000000 .Values.gatekeeper.upstream.responseHeaderTimeout }}
# upstream-keepalive-timeout is the upstream keepalive timeout
upstream-keepalive-timeout: {{ default  120000000000 .Values.gatekeeper.upstream.keepaliveTimeout }}
{{- end }}

{{- if .Values.gatekeeper.addClaims }}
# extra claims from the token and inject into headers, e.g given_name -> X-Auth-Given-Name
add-claims: {{ .Values.gatekeeper.addClaims }}
{{- end }}

resources: {{ $resources | toJson }}
